Stan Math Library: stan/math/prim/mat/fun/read_cov_matrix.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
read_cov_matrix.hpp File Reference
`#include <stan/math/prim/mat/fun/read_cov_L.hpp>`
`#include <stan/math/prim/mat/fun/multiply_lower_tri_self_transpose.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::read_cov_matrix (const Eigen::Array< T, Eigen::Dynamic, 1 > &CPCs, const Eigen::Array< T, Eigen::Dynamic, 1 > &sds, T &log_prob)
| A generally worse alternative to call prior to evaluating the density of an elliptical distribution. More...
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::read_cov_matrix (const Eigen::Array< T, Eigen::Dynamic, 1 > &CPCs, const Eigen::Array< T, Eigen::Dynamic, 1 > &sds)
| Builds a covariance matrix from CPCs and standard deviations. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.